Module prometheus

Module prometheus 

Available on crate feature metrics only.
Prometheus exposition for collected metrics.

This module is only compiled when the metrics feature is enabled. It translates a MetricsSnapshot into the Prometheus text exposition format, which can be served from any HTTP handler (kept out of this crate to avoid pulling in a web server).

Structs

PrometheusExporter
Holds Prometheus counters mirroring the executor’s metrics.