pub struct PrometheusExporter { /* private fields */ }Available on crate feature
metrics only.Expand description
Holds Prometheus counters mirroring the executor’s metrics.
Implementations
Sourceimpl PrometheusExporter
impl PrometheusExporter
Sourcepub fn registry(&self) -> &Registry
pub fn registry(&self) -> &Registry
The underlying registry, e.g. to register additional collectors.
Sourcepub fn update(&self, snap: &MetricsSnapshot)
pub fn update(&self, snap: &MetricsSnapshot)
Overwrite counter values from a snapshot.
Prometheus counters are monotonic, so we only ever move them forward by the delta between their current value and the snapshot.